==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebForOfStateDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfStateDetailDescription } from "./WebForOfStateDetailDescription";
/**
 * @hidden
 */
var WebForOfStateDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfStateDetailDescriptionMetadata, _super);
    function WebForOfStateDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateDetailDescriptionMetadata.b = function (a) {
        if (WebForOfStateDetailDescriptionMetadata.a == null) {
            WebForOfStateDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateDetailDescriptionMetadata.c(WebForOfStateDetailDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfStateDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("StartIndex", "Number:double");
        a.item("ChunkSize", "Number:double");
    };
    WebForOfStateDetailDescriptionMetadata.d = function (a) {
        WebForOfStateDetailDescriptionMetadata.b(a);
        a.ad("WebForOfStateDetail", function () { return new WebForOfStateDetailDescription(); });
        a.ac("WebForOfStateDetail", WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.$t = markType(WebForOfStateDetailDescriptionMetadata, 'WebForOfStateDetailDescriptionMetadata');
    WebForOfStateDetailDescriptionMetadata.a = null;
    return WebForOfStateDetailDescriptionMetadata;
}(Base));
export { WebForOfStateDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebForOfStateDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfStateDetailDescription } from "./WebForOfStateDetailDescription";
/**
 * @hidden
 */
var WebForOfStateDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfStateDetailDescriptionMetadata, _super);
    function WebForOfStateDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateDetailDescriptionMetadata.b = function (a) {
        if (WebForOfStateDetailDescriptionMetadata.a == null) {
            WebForOfStateDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateDetailDescriptionMetadata.c(WebForOfStateDetailDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfStateDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("StartIndex", "Number:double");
        a.item("ChunkSize", "Number:double");
    };
    WebForOfStateDetailDescriptionMetadata.d = function (a) {
        WebForOfStateDetailDescriptionMetadata.b(a);
        a.ae("WebForOfStateDetail", function () { return new WebForOfStateDetailDescription(); });
        a.ad("WebForOfStateDetail", WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.$t = markType(WebForOfStateDetailDescriptionMetadata, 'WebForOfStateDetailDescriptionMetadata');
    WebForOfStateDetailDescriptionMetadata.a = null;
    return WebForOfStateDetailDescriptionMetadata;
}(Base));
export { WebForOfStateDetailDescriptionMetadata };
